[Gluster-Maintainers] [gluster-packaging] glusterfs-3.10.1 released

Patrick Matthäi pmatthaei at debian.org
Fri Mar 31 09:47:34 UTC 2017


Am 30.03.2017 um 20:36 schrieb Gluster Build System:
>
> SRC: http://bits.gluster.org/pub/gluster/glusterfs/src/glusterfs-3.10.1.tar.gz
>
> This release is made off jenkins-release-189
>
> -- Gluster Build System
> _______________________________________________
> packaging mailing list
> packaging at gluster.org
> http://lists.gluster.org/mailman/listinfo/packaging

Thanks for this release, first after 3.8.x which is also building on
Debian again ;)
I have uploaded it to the Debian experimental suite:
https://buildd.debian.org/status/package.php?p=glusterfs&suite=experimental

Attached a little patch for 3.10.1

-- 
/*
Mit freundlichem Gruß / With kind regards,
 Patrick Matthäi
 GNU/Linux Debian Developer

  Blog: http://www.linux-dev.org/
E-Mail: pmatthaei at debian.org
        patrick at linux-dev.org
*/

-------------- next part --------------
# Fix some spelling errors reported by lintian.

diff -Naur glusterfs-3.10.1.orig/cli/src/cli.c glusterfs-3.10.1/cli/src/cli.c
--- glusterfs-3.10.1.orig/cli/src/cli.c	2017-03-30 20:35:57.179620520 +0200
+++ glusterfs-3.10.1/cli/src/cli.c	2017-03-31 09:37:10.878471050 +0200
@@ -380,7 +380,7 @@
         oarg = strtail (opt, "timeout=");
         if (oarg) {
                 if (!is_valid_int (oarg) || atoi(oarg) <= 0) {
-                        cli_err ("timeout value should be a postive integer");
+                        cli_err ("timeout value should be a positive integer");
                         return -2; /* -2 instead of -1 to avoid unknown option
                                       error */
                 }
diff -Naur glusterfs-3.10.1.orig/events/src/glustereventsd.py glusterfs-3.10.1/events/src/glustereventsd.py
--- glusterfs-3.10.1.orig/events/src/glustereventsd.py	2017-03-30 20:35:57.191620544 +0200
+++ glusterfs-3.10.1/events/src/glustereventsd.py	2017-03-31 09:47:22.427162661 +0200
@@ -59,7 +59,7 @@
         try:
             # Event Type to Function Map, Recieved event data will be in
             # the form <TIMESTAMP> <TYPE> <DETAIL>, Get Event name for the
-            # recieved Type/Key and construct a function name starting with
+            # received Type/Key and construct a function name starting with
             # handle_ For example: handle_event_volume_create
             func_name = "handle_" + all_events[int(key)].lower()
         except IndexError:
diff -Naur glusterfs-3.10.1.orig/xlators/cluster/ec/src/ec-code.c glusterfs-3.10.1/xlators/cluster/ec/src/ec-code.c
--- glusterfs-3.10.1.orig/xlators/cluster/ec/src/ec-code.c	2017-03-30 20:35:57.276620714 +0200
+++ glusterfs-3.10.1/xlators/cluster/ec/src/ec-code.c	2017-03-31 09:37:47.894271062 +0200
@@ -1032,7 +1032,7 @@
 
     if (file.error) {
         gf_msg(xl->name, GF_LOG_WARNING, 0, EC_MSG_EXTENSION_FAILED,
-               "Unable to detemine supported CPU extensions. Not using any "
+               "Unable to determine supported CPU extensions. Not using any "
                "cpu extensions");
 
         gen = NULL;
diff -Naur glusterfs-3.10.1.orig/xlators/protocol/client/src/client-callback.c glusterfs-3.10.1/xlators/protocol/client/src/client-callback.c
--- glusterfs-3.10.1.orig/xlators/protocol/client/src/client-callback.c	2017-03-30 20:35:57.343620848 +0200
+++ glusterfs-3.10.1/xlators/protocol/client/src/client-callback.c	2017-03-31 09:47:06.887246823 +0200
@@ -115,7 +115,7 @@
         if (ret < 0)
                 goto out;
 
-        gf_msg_trace (THIS->name, 0, "Cache invalidation cbk recieved for gfid:"
+        gf_msg_trace (THIS->name, 0, "Cache invalidation cbk received for gfid:"
                       " %s, ret = %d", ca_req.gfid, ret);
 
         default_notify (THIS, GF_EVENT_UPCALL, &upcall_data);


More information about the maintainers mailing list
diff -Naur glusterfs-3.10.1.orig/xlators/performance/md-cache/src/md-cache.c glusterfs-3.10.1/xlators/performance/md-cache/src/md-cache.c
--- glusterfs-3.10.1.orig/xlators/performance/md-cache/src/md-cache.c	2017-03-30 20:35:57.339620840 +0200
+++ glusterfs-3.10.1/xlators/performance/md-cache/src/md-cache.c	2017-03-31 09:47:13.499211014 +0200
@@ -38,8 +38,8 @@
         uint64_t negative_lookup; /* No. of negative lookups */
         uint64_t nameless_lookup; /* No. of negative lookups that were sent
                                      sent to bricks */
-        uint64_t stat_invals; /* No. of invalidates recieved from upcall*/
-        uint64_t xattr_invals; /* No. of invalidates recieved from upcall*/
+        uint64_t stat_invals; /* No. of invalidates received from upcall*/
+        uint64_t xattr_invals; /* No. of invalidates received from upcall*/
         uint64_t need_lookup; /* No. of lookups issued, because other xlators
                                * requested for explicit lookup */
         gf_lock_t lock;
@@ -682,7 +682,7 @@
         LOCK (&mdc->lock);
         {
                 if (mdc->xattr) {
-                        gf_msg_trace ("md-cache", 0, "deleteing the old xattr "
+                        gf_msg_trace ("md-cache", 0, "deleting the old xattr "
                               "cache (%s)", uuid_utoa (inode->gfid));
                         dict_unref (mdc->xattr);
 			mdc->xattr = NULL;
@@ -2597,9 +2597,9 @@
                            conf->mdc_counter.nameless_lookup);
         gf_proc_dump_write("negative_lookup_count", "%"PRId64,
                            conf->mdc_counter.negative_lookup);
-        gf_proc_dump_write("stat_invalidations_recieved", "%"PRId64,
+        gf_proc_dump_write("stat_invalidations_received", "%"PRId64,
                            conf->mdc_counter.stat_invals);
-        gf_proc_dump_write("xattr_invalidations_recieved", "%"PRId64,
+        gf_proc_dump_write("xattr_invalidations_received", "%"PRId64,
                            conf->mdc_counter.xattr_invals);
 
         return 0;